@@ -120,6 +120,7 @@ static char *models[] =
 	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
 	"Intel\\(R\\) Core\\(TM\\) i7-6700T CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
 	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\) i7-8550U CPU @ [0-3]\\.[0-9]{2]GHz", "Core i7",
 	"Genuine Intel\\(R\\) CPU            2140  @ [0-3]\\.[0-9]{2}GHz", "Pentium 4",
 	"Intel\\(R\\) Atom\\(TM\\) CPU N[0-9]{2}0   @ [0-3]\\.[0-9]{2}GHz", "Atom",
 #else
@@ -217,6 +218,7 @@ static char *models[] =
 	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM) i7-6600U CPU @ 2.60GHz", "Core i7",
 	"Intel(R) Core(TM) i7-6700T CPU @ 2.80GHz", "Core i7",
+	"Intel(R) Core(TM) i7-8550U CPU @ 1.80GHz", "Core i7",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
 	"Intel(R) Atom(TM) CPU N450   @ 1.66GHz", "Atom",
 	"Intel(R) Atom(TM) CPU N270   @ 1.60GHz", "Atom",
